| Title: | Optimum Block Length |
|---|---|
| Description: | Obtain optimum block from Non-overlapping Block Bootstrap method. |
| Authors: | Daniel James [cre, aut], Ayinde Kayode [aut] |
| Maintainer: | Daniel James <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.2.1 |
| Built: | 2026-05-17 06:03:12 UTC |
| Source: | https://github.com/cran/OBL |
OBL: Optimal Block Length
Compute Optimal Block Length for Non-overlapping, Overlapping, Circular Block, tapered moving, and tapered circular Block Bootstrap method
OBL: Optimal Block Length
Compute Optimal Block Length for Non-overlapping, Overlapping, Circular Block, tapered moving, and tapered circular Block Bootstrap method
blockboot( ts, R, seed, n_cores, methods = c("optnbb", "optmbb", "optcbb", "opttmbb", "opttcbb") ) lolliblock( ts, R, seed, n_cores, methods = c("optnbb", "optmbb", "optcbb", "opttmbb", "opttcbb") )blockboot( ts, R, seed, n_cores, methods = c("optnbb", "optmbb", "optcbb", "opttmbb", "opttcbb") ) lolliblock( ts, R, seed, n_cores, methods = c("optnbb", "optmbb", "optcbb", "opttmbb", "opttcbb") )
ts |
univariate time series |
R |
number of resample |
seed |
RNG seed |
n_cores |
number of core(s) to be used on your operaterating system |
methods |
"optnbb", "optmbb", "optcbb", "opttmbb", "opttcbb" |
A data frame get printed to the console
A data frame get printed to the console
blockboot: package helps to obtain the optimal block length of a time series data
lolliblock: package helps to obtain the optimal block length of a time series data
set.seed(289805) ts <- arima.sim(n = 3, model = list(ar = 0.8, order = c(1, 0, 0)), sd = 1) blockboot(ts = ts, R = 2, seed = 6, n_cores = 1) set.seed(289805) ts <- arima.sim(n = 3, model = list(ar = 0.8, order = c(1, 0, 0)), sd = 1) lolliblock(ts, R = 2, seed = 6, n_cores = 1)set.seed(289805) ts <- arima.sim(n = 3, model = list(ar = 0.8, order = c(1, 0, 0)), sd = 1) blockboot(ts = ts, R = 2, seed = 6, n_cores = 1) set.seed(289805) ts <- arima.sim(n = 3, model = list(ar = 0.8, order = c(1, 0, 0)), sd = 1) lolliblock(ts, R = 2, seed = 6, n_cores = 1)
arima.sim returns the sum of all the values present in its arguments.
tsts
A time series data with 10 rows and 1 variables:
price, in US dollars
weight of the diamond, in carats
...
A dataset containing simulated univariate time series of 10 ts.
It returns a univairate time series data It could be a vector
Simulated data generated with the following code: set.seed(289805) ts <- stats::arima.sim(n = 10, model = list(ar = 0.8, order = c(1, 0, 0)), sd = 1)
set.seed(289805) ts <- stats::arima.sim(n = 10, model = list(ar = 0.8, order = c(1, 0, 0)), sd = 1)set.seed(289805) ts <- stats::arima.sim(n = 10, model = list(ar = 0.8, order = c(1, 0, 0)), sd = 1)